==> nuxeo-automation-io-5.9.5-sources.jar: org/nuxeo/ecm/automation/jaxrs/io/documents/BlobsWriter.java <==
/*
 * Copyright (c) 2006-2011 Nuxeo SA (http://nuxeo.com/) and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     bstefanescu
 *
 * $Id$
 */

package org.nuxeo.ecm.automation.jaxrs.io.documents;

import java.io.IOException;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

import javax.mail.MessagingException;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;

/**
 * @author <a href="mailto:bs@nuxeo.com">Bogdan Stefanescu</a>
 */
@Provider
@Produces("multipart/mixed")
public class BlobsWriter implements MessageBodyWriter<MultipartBlobs> {

    @Override
    public void writeTo(MultipartBlobs blobs, Class<?> type, Type genericType,
            Annotation[] annotations, MediaType mediaType,
            MultivaluedMap<String, Object> httpHeaders,
            OutputStream entityStream) throws IOException {
        try {
            httpHeaders.putSingle("Content-Type", blobs.getContentType());
            blobs.writeTo(entityStream);
            entityStream.flush();
        } catch (MessagingException e) {
            throw new IOException("Failed to return blobs", e);
        }
    }

    @Override
    public long getSize(MultipartBlobs arg0, Class<?> arg1, Type arg2,
            Annotation[] arg3, MediaType arg4) {
        return -1;
    }

    @Override
    public boolean isWriteable(Class<?> arg0, Type type, Annotation[] arg2,
            MediaType arg3) {
        return MultipartBlobs.class == arg0;
    }

}

==> nuxeo-automation-io-7.4-sources.jar: org/nuxeo/ecm/automation/jaxrs/io/documents/BlobsWriter.java <==
/*
 * Copyright (c) 2006-2011 Nuxeo SA (http://nuxeo.com/) and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     bstefanescu
 *
 * $Id$
 */

package org.nuxeo.ecm.automation.jaxrs.io.documents;

import java.io.IOException;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

import javax.mail.MessagingException;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;

/**
 * @author <a href="mailto:bs@nuxeo.com">Bogdan Stefanescu</a>
 */
@Provider
@Produces("multipart/mixed")
public class BlobsWriter implements MessageBodyWriter<MultipartBlobs> {

    @Override
    public void writeTo(MultipartBlobs blobs, Class<?> type, Type genericType, Annotation[] annotations,
            MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream entityStream)
            throws IOException {
        try {
            httpHeaders.putSingle("Content-Type", blobs.getContentType());
            blobs.writeTo(entityStream);
            entityStream.flush();
        } catch (MessagingException e) {
            throw new IOException("Failed to return blobs", e);
        }
    }

    @Override
    public long getSize(MultipartBlobs arg0, Class<?> arg1, Type arg2, Annotation[] arg3, MediaType arg4) {
        return -1;
    }

    @Override
    public boolean isWriteable(Class<?> arg0, Type type, Annotation[] arg2, MediaType arg3) {
        return MultipartBlobs.class == arg0;
    }

}
